summaryrefslogtreecommitdiffstats
path: root/wp-admin/nav-menus.php
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-09-19 04:51:22 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-09-19 04:51:22 +0000
commitfc0a79914946dac00ccd51b1aacffe267de7210e (patch)
tree1403384efbfe8f8776ff60aaa40f7d535c02c822 /wp-admin/nav-menus.php
parentReleasing progress-linux version 6.5.5+dfsg1-1~progress7.99u1. (diff)
downloadwordpress-fc0a79914946dac00ccd51b1aacffe267de7210e.tar.xz
wordpress-fc0a79914946dac00ccd51b1aacffe267de7210e.zip
Merging upstream version 6.6.1+dfsg1.
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'wp-admin/nav-menus.php')
-rw-r--r--wp-admin/nav-menus.php10
1 files changed, 6 insertions, 4 deletions
diff --git a/wp-admin/nav-menus.php b/wp-admin/nav-menus.php
index 93b3c5e..7f22e4f 100644
--- a/wp-admin/nav-menus.php
+++ b/wp-admin/nav-menus.php
@@ -580,10 +580,12 @@ $nav_menus_l10n = array(
'under' => __( 'Under %s' ),
/* translators: %s: Previous item name. */
'outFrom' => __( 'Out from under %s' ),
- /* translators: 1: Item name, 2: Item position, 3: Total number of items. */
- 'menuFocus' => __( '%1$s. Menu item %2$d of %3$d.' ),
- /* translators: 1: Item name, 2: Item position, 3: Parent item name. */
- 'subMenuFocus' => __( '%1$s. Sub item number %2$d under %3$s.' ),
+ /* translators: 1: Item name, 2: Item type, 3: Item index, 4: Total items. */
+ 'menuFocus' => __( 'Edit %1$s (%2$s, %3$d of %4$d)' ),
+ /* translators: 1: Item name, 2: Item type, 3: Item index, 4: Total items, 5: Item parent. */
+ 'subMenuFocus' => __( 'Edit %1$s (%2$s, sub-item %3$d of %4$d under %5$s)' ),
+ /* translators: 1: Item name, 2: Item type, 3: Item index, 4: Total items, 5: Item parent, 6: Item depth. */
+ 'subMenuMoreDepthFocus' => __( 'Edit %1$s (%2$s, sub-item %3$d of %4$d under %5$s, level %6$d)' ),
/* translators: %s: Item name. */
'menuItemDeletion' => __( 'item %s' ),
/* translators: %s: Item name. */